==> apache-streampipes-0.68.0-incubating-source-release.zip: apache-streampipes-0.68.0-incubating/ui/src/app/connect/filter/filter.pipe.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import {Pipe, PipeTransform} from '@angular/core';
import {AdapterDescriptionUnion} from "../../core-model/gen/streampipes-model";

@Pipe({
    name: 'filter'
})

export class FilterPipe implements PipeTransform {

    transform(adapterDescriptions: AdapterDescriptionUnion[], filterTerm?: any): any{
        //check if search filterTerm is undefined
        if(filterTerm == undefined || !adapterDescriptions) return adapterDescriptions;
        return adapterDescriptions.filter(adapterDescription => {
            if (adapterDescription.name == null) {
                return true;
            } else {
                adapterDescription.name.replace(' ', '_');
                return adapterDescription.name.toLowerCase().includes(filterTerm.toLowerCase()) || adapterDescription.description.toLowerCase().includes(filterTerm.toLowerCase());
            }
        });
    }
}

==> apache-streampipes-0.69.0-incubating-source-release.zip: apache-streampipes-0.69.0-incubating/ui/src/app/connect/filter/filter.pipe.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import { Pipe, PipeTransform } from '@angular/core';
import { AdapterDescriptionUnion } from '@streampipes/platform-services';

@Pipe({
    name: 'filter'
})

export class FilterPipe implements PipeTransform {

    transform(adapterDescriptions: AdapterDescriptionUnion[], filterTerm?: any): any {
        // check if search filterTerm is undefined
        if (filterTerm === undefined || !adapterDescriptions) { return adapterDescriptions; }
        return adapterDescriptions.filter(adapterDescription => {
            if (adapterDescription.name == null) {
                return true;
            } else {
                adapterDescription.name.replace(' ', '_');
                return adapterDescription.name.toLowerCase().includes(filterTerm.toLowerCase()) ||
                    adapterDescription.description.toLowerCase().includes(filterTerm.toLowerCase());
            }
        });
    }
}
